@@ -1,7 +1,7 @@
 /**
  * addfiles.c - Interface for adding files to the project
  *
- *  Copyright 2011 Andreas Rönnquist
+ *  Copyright 2011-2012 Andreas Rönnquist
  *
  * This file is part of SciteProj
  *
@@ -22,6 +22,9 @@
  
 #include <gtk/gtk.h>
 #include <glib-object.h>
+#include <glib/gi18n.h>
+
+#include <locale.h>
 
 #include "clicked_node.h"
 
@@ -139,7 +142,12 @@ void addfile_menu_cb()
  */
 void menu_add_widget_cb(GtkUIManager *ui, GtkWidget *widget, GtkContainer *container)
 {
+	// use Grid instead of box packing on GTK3
+#if GTK_MAJOR_VERSION>=3
+	gtk_grid_attach(GTK_GRID(container),widget,0,0,1,1);
+#else
 	gtk_box_pack_start(GTK_BOX(container), widget, FALSE, FALSE, 0);
+#endif
 	gtk_widget_show(widget);
 }
 
@@ -225,27 +233,46 @@ void ask_name_add_group(GtkTreeIter *nodeIter)
 	GtkWidget* gtkEntry = NULL;
 	GtkWidget* gtkLabel = NULL;
 	GtkWidget* table = NULL;
+	
+#if GTK_MAJOR_VERSION<3
 	GtkAttachOptions options = (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL);
+#endif
 	const gchar *groupName = NULL;
 	gint dialogResponse;
 	
 	
 	// Create a dialog box with a nicely-centered text entry widget
-	dialog = gtk_dialog_new_with_buttons("Choose Group Name", NULL, GTK_DIALOG_MODAL, GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
+	dialog = gtk_dialog_new_with_buttons(_("Create Group"), NULL, GTK_DIALOG_MODAL, GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
 	
 	g_signal_connect(dialog, "response",  G_CALLBACK(gtk_widget_hide), dialog);
 	
 	gtk_container_set_border_width(GTK_CONTAINER(dialog), 0);
-	
+#if GTK_MAJOR_VERSION>=3
+	table=gtk_grid_new();
+	gtk_grid_set_row_spacing (GTK_GRID (table), 6);
+	gtk_grid_set_column_spacing(GTK_GRID(table),6);
+
+#else
 	table = gtk_table_new(1, 2, FALSE);
+#endif
 	
-	gtkLabel = gtk_label_new("Enter name of new group:");
+	gtkLabel = gtk_label_new(_("Enter name of new group:"));
+	
+#if GTK_MAJOR_VERSION>=3
+	gtk_grid_attach(GTK_GRID(table),gtkLabel,0,0,3,1);
+#else
 	gtk_table_attach(GTK_TABLE(table), gtkLabel, 0, 1, 0, 1, options, options, 5, 5);
-	
+#endif
+
 	gtkEntry = gtk_entry_new();
 
 	g_signal_connect(G_OBJECT(gtkEntry), "activate", G_CALLBACK(entry_widget_activated_cb), dialog);
+
+#if GTK_MAJOR_VERSION>=3
+	gtk_grid_attach_next_to(GTK_GRID(table),gtkEntry,gtkLabel,GTK_POS_RIGHT,3,1);
+#else
 	gtk_table_attach(GTK_TABLE(table), gtkEntry, 1, 2, 0, 1, options, options, 5, 5);
+#endif
 	
 	
 	GtkWidget *container_vbox=gtk_dialog_get_content_area(GTK_DIALOG(dialog));
