@@ -1,7 +1,7 @@
 /**
  * drag_drop.c - Drag-and-drop support for SciteProj
  *
- *  Copyright 2006 Roy Wood, 2009-2011 Andreas Rönnquist
+ *  Copyright 2006 Roy Wood, 2009-2012 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  * 
@@ -23,7 +23,9 @@
 
 #include <gtk/gtk.h>
 #include <glib.h>
+#include <glib/gi18n.h>
 
+#include <locale.h>
 
 
 #include "drag_drop.h"
