@@ -1,7 +1,7 @@
 /**
  * file_utils.c - file utilities for SciteProj
  *
- *  Copyright 2009-2011 Andreas Rönnquist
+ *  Copyright 2009-2012 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  * 
@@ -22,6 +22,10 @@
 
 #include <string.h>
 #include <glib.h>
+#include <glib/gi18n.h>
+
+#include <locale.h>
+
 
 #include "file_utils.h"
 
