@@ -1,7 +1,7 @@
 /**
  * main.c - main for SciteProj
  *
- *  Copyright 2006 Roy Wood, 2009-2011 Andreas Rönnquist
+ *  Copyright 2006 Roy Wood, 2009-2012 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  * 
@@ -25,6 +25,9 @@
 #include <gtk/gtk.h>
 #include <glib.h>
 #include <string.h>
+#include <glib/gi18n.h>
+
+#include <locale.h>
 
 #include "clicked_node.h"
 #include "gui.h"
@@ -43,9 +46,6 @@ static struct CommandLineIndata {
 } cmd;
 
 
-static void parse_cmd_options(int argc,char *argv[]);
-
-
 /*
  *		Program main entry
  */
@@ -54,19 +54,109 @@ int main(int argc, char *argv[])
 	int returnCode = EXIT_FAILURE;
 	GError *err = NULL;
 	gchar *file_to_load=NULL;
+	GOptionContext *context=NULL;
 	
-	parse_cmd_options(argc,argv);
+	static gboolean version=FALSE;
+	static gchar *scite_instance=NULL;
+	//static gboolean gene
+	static gchar *generate_xml_file=NULL;
+	static int max_depth_generated=-1;
+	
+	static const GOptionEntry options[]={
+		{ "version",		'v',	0, G_OPTION_ARG_NONE,		&version,
+			N_("Show program version and quit")},
+		{ "scite",			's',	0, G_OPTION_ARG_STRING,		&scite_instance,
+			N_("Set a filename for the instance of SciTE to open"),	N_("SCITE_FILENAME")},
+		{ "generate",		'g',	0, G_OPTION_ARG_STRING,		&generate_xml_file,
+			N_("Generate a sciteproj project file with name XML_FILENAME, recursively from current folder"),
+			N_("XML_FILENAME")},
+		{ "max_depth",		'm',	0, G_OPTION_ARG_INT,	&max_depth_generated,
+			N_("Set maximum depth of folders to read through to MAX_DEPTH when generating project file"),
+			N_("MAX_DEPTH")},
+		{ NULL }
+	};
+	
+	// Init gettext stuff
+	setlocale(LC_ALL,"");
+	
+	bindtextdomain(PACKAGE,LOCALEDIR);
+	bind_textdomain_codeset(PACKAGE,"");
+	textdomain(PACKAGE);
+	
+	gchar *sciteproj_description=NULL;
+	sciteproj_description=g_strdup_printf(_("SciTE Project Manager"));
+	
+	gchar *full_desc_string=g_strdup_printf("- %s",sciteproj_description);
+	
+	context=g_option_context_new(full_desc_string);
+	g_option_context_add_main_entries(context,options,NULL);
+	if (!g_option_context_parse(context, &argc, &argv, &err)) {
+		g_print(_("option parsing failed: %s"),err->message);
+		printf("\n");
+		exit(EXIT_FAILURE);
+	}
+	
+	g_free(sciteproj_description);
+	g_free(full_desc_string);
+	
+	/*
+		Interpret the options
+	 */
+	/*
+		set instance of SciTE to run
+	*/
+	if (scite_instance) {
+		cmd.scite_filename=scite_instance;
+	}
+	
+	/*
+		Generate a project file going down at max max_depth levels in the folder
+		hierarchy
+	*/
+	if (generate_xml_file) {
+		int max_depth=4;
+		if (max_depth_generated!=-1) max_depth=max_depth_generated;
+		
+		//gboolean result=folder_to_xml(folder,filename,max_depth);
+		gboolean result=folder_to_xml(".",generate_xml_file,max_depth);
+		
+		if (result) {
+			printf(_("Generated '%s' successfully!"),generate_xml_file);
+			printf("\n\n");
+		} else {
+			exit(EXIT_FAILURE);
+		}
+		
+		exit(EXIT_SUCCESS);
+	}
+	
+	init_version_string();
+	
+	/*
+		Show SciteProj version 
+	*/
+	if (version) {
+		show_version();
+		printf("\n");
+		done_version_string();
+		exit(EXIT_SUCCESS);
+	}
+
+	// If there is any indata left - load it as a sciteproj project
+	if (argc>1)
+		cmd.file_to_load=g_strdup_printf("%s",argv[1]);
 	
 	// Init gtk
 	gtk_init(&argc, &argv);
 	
-	g_thread_init(NULL);
+	g_type_init();
 	
 	init_file_utils();
 	
-	// Init sciteproj prefs
+	// Init preferences
 	if (!init_prefs(&err)) {
-		g_print("Error initing preferences: %s", err->message);
+		g_print(_("Error initing preferences: %s"), err->message);
+		done_version_string();
 		return EXIT_FAILURE;
 	}
 	
@@ -83,7 +173,7 @@ int main(int argc, char *argv[])
 				cmd.scite_filename=g_strdup(env_filename);
 			}
 		} else {
-			g_warning("Environment variable exists, but doesn't point to a folder containing scite.");
+			g_warning(_("Environment variable exists, but doesn't point to a folder containing scite."));
 		}
 
 		if (env_filename!=NULL) g_free(env_filename);
@@ -93,7 +183,7 @@ int main(int argc, char *argv[])
 				cmd.scite_filename=g_strdup(env_filename);
 			}
 		} else {
-			g_warning("Environment variable exists, but doesn't point to a folder containing scite.");
+			g_warning(_("Environment variable exists, but doesn't point to a folder containing scite."));
 		}
 	}
 	
@@ -110,8 +200,8 @@ int main(int argc, char *argv[])
 			gPrefs.scite_path=g_strdup(cmd.scite_filename);
 			
 		} else {
-			g_print("Couldn't find a SciTE executable named '%s'!\n",cmd.scite_filename);
-			g_print("Checking for SciTE in the standard locations instead.\n");
+			g_print(_("Couldn't find a SciTE executable named '%s'!\n"),cmd.scite_filename);
+			g_print(_("Checking for SciTE in the standard locations instead.\n"));
 		}
 	} 
 	
@@ -124,15 +214,16 @@ int main(int argc, char *argv[])
 	// Check for SciTE
 	if (!check_if_scite_exists()) {
 		GtkWidget *warningDialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, 
-				"Warning! Couldn't locate SciTE!\n"
-				"Program will start, but you won't be able to open SciTE to edit files.");
+				_("Warning! Couldn't locate SciTE!\n"
+				"Program will start, but you won't be able to open SciTE to edit files."));
 		gtk_dialog_run(GTK_DIALOG(warningDialog));
 		gtk_widget_destroy(warningDialog);
 	}
 	
 	// Set up the GUI
 	if (!setup_gui(&err)) {
-		g_print("Could not initialize application globals: %s\n", err->message);
+		g_print("Could not setup the gui: %s", err->message);
+		g_print("\n");
 		goto EXITPOINT;
 	}
 	
@@ -145,10 +236,11 @@ int main(int argc, char *argv[])
 	}
 	
 	
+	
 	// Was a project file specified on the command line?
 	if (file_to_load!=NULL) {
 		if (!load_project(file_to_load, &err)) {
-			GtkWidget *errDialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "An error occurred while trying to load the specified project file: %s", err->message);
+			GtkWidget *errDialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,_("An error occurred while trying to load the specified project file: %s"), err->message);
 			gtk_dialog_run(GTK_DIALOG(errDialog));
 			gtk_widget_destroy(errDialog);
 			
@@ -176,108 +268,9 @@ EXITPOINT:
 	
 	done_prefs();
 	
+	done_version_string();
+	
 	if (err) g_error_free(err);
 	
 	return returnCode;
 }
-
-
-/**
- *		parse_cmd_options
- *		Parses the argc/argv data
- */
-static void parse_cmd_options(int argc,char *argv[])
-{
-	gint i;
-	
-	gchar *indata_left=NULL;
-
-	
-	for (i=1;i<argc;i++) {
-		if (!strncmp(argv[i],"--help",6)) {
-			g_print("\n");
-			g_print("Usage: %s [OPTION] [FILE]...",
-				g_basename(argv[0]));
-			
-			g_print("\n\n");
-			g_print("%s\n\n", "Options can be one of the following:");
-			g_print("%s\n", "  --help                            display this help and exit");
-			g_print("%s\n", "  --version                         show version of sciteproj and exit");
-			g_print("%s\n", "  --scite FILENAME                  set a filename for the instance of SciTE to open");			
-			g_print("%s\n", "  --generate FILENAME [MAX_DEPTH]   generate a sciteproj project file with name FILENAME,");
-			g_print("%s\n", "                                      recursively from current folder contents, at most");
-			g_print("%s\n", "                                      MAX_DEPTH folders down in the hierarchy");
-			g_print("\n");
-			exit(EXIT_SUCCESS);
-			
-		} else if (!strncmp(argv[i],"--scite",7)) {
-			const gchar *p = argv[i + 1];
-
-			//cmd.set_scite_folder = TRUE;
-			cmd.scite_filename= NULL;
-			if (p && *p != '\0' && *p != '-') {
-				/*
-				if (!strncmp(p, "mailto:", 7))
-					cmd.scite_folder = p + 7;
-				else
-				*/
-				cmd.scite_filename= p;
-				i++;
-			}	
-		} else if (!strncmp(argv[i],"--version",9)) {
-			
-			show_version();
-			exit(EXIT_SUCCESS);
-		} else if (!strncmp(argv[i],"--generate",10)) {
-			
-			if ((argc!=3) && (argc!=4)) {
-				
-				printf("\nThe syntax for that command is:\n\n");
-				printf("sciteproj --generate FILENAME [MAX_DEPTH]\n\n");
-				
-				exit(EXIT_FAILURE);
-			}
-			
-			gchar *filename=argv[2];
-			int max_depth=4;
-			
-			// 4 inputs (means we should expect an max_depth value too)
-			// sciteproj --generate file.xml [depth]
-			if (argc==4) {
-				gchar *max_depth_s=argv[3];
-				
-				if (!is_integer(max_depth_s)) {
-					printf("Expected an integer as max_depth...\n\n");
-					exit(EXIT_FAILURE);
-				} else {
-					max_depth=atoi(max_depth_s);
-				}
-			}
-			
-			//gboolean result=folder_to_xml(folder,filename,max_depth);
-			gboolean result=folder_to_xml(".",filename,max_depth);
-			
-			if (result) {
-				printf("Generated '%s' successfully!\n\n",filename);
-			} else {
-				exit(EXIT_FAILURE);
-			}
-			
-			exit(EXIT_SUCCESS);
-		} else {
-			
-			indata_left=argv[i];
-		}
-	}
-	
-#ifdef _DEBUG
-	if (cmd.scite_filename!=NULL) {
-		g_print("scite_filename:%s\n",cmd.scite_filename);
-	}
-#endif
-	
-	if (indata_left!=NULL) {
-		cmd.file_to_load=g_strdup(indata_left);
-	}
-	
-}
