@@ -1,7 +1,7 @@
 /**
  * prefs.c - prefs for SciteProj
  *
- *  Copyright 2006 Roy Wood, 2009-2011 Andreas Rönnquist
+ *  Copyright 2006 Roy Wood, 2009-2012 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  * 
@@ -65,6 +65,8 @@ gchar *default_config_string=(gchar*)"" \
 				"show_recent=FALSE\n"
 				"recent_add_to_bottom=FALSE\n"
 				"\n"
+				"hide_statusbar=FALSE\n"
+				"\n"
 				"\n";
 
 
@@ -222,6 +224,12 @@ gboolean check_config_string(gchar *in_config)
 				gPrefs.search_trim_results=TRUE;
 			}
 		}
+		
+		if (g_ascii_strcasecmp(tempstring,"hide_statusbar")==0) {
+			if (g_ascii_strcasecmp(value,"TRUE")==0) {
+				gPrefs.hide_statusbar=TRUE;
+			}
+		}
 	}
 	
 	if (tempstring!=NULL) g_free(tempstring);
@@ -282,6 +290,8 @@ gboolean init_prefs(GError **err)
 	
 	gPrefs.search_trim_results=FALSE;
 	
+	gPrefs.hide_statusbar=FALSE;
+	
 
 	// the result of g_get_user_config_dir doesn't need to be freed, so we
 	// dont need to put it in a pointer of its own.
