@@ -1,7 +1,7 @@
 /**
  * properties_dialog.c - Properties Dialogs code for SciteProj
  *
- *  Copyright 2009-2011 Andreas Rönnquist
+ *  Copyright 2009-2012 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  * 
@@ -24,6 +24,10 @@
 #include <gtk/gtk.h>
 #include <string.h>
 #include <sys/stat.h>
+#include <glib/gi18n.h>
+
+#include <locale.h>
+
 
 #include "properties_dialog.h"
 #include "tree_manipulation.h"
@@ -124,12 +128,12 @@ void group_properties_gui(GtkTreeModel *tree_model,GtkTreeIter *iter)
 		
 	number_of_files_string=g_strdup_printf("%d",number_of_files);
 	
-	dialog=gtk_dialog_new_with_buttons("Group Properties",NULL,GTK_DIALOG_MODAL,GTK_STOCK_OK,GTK_RESPONSE_OK,NULL);
+	dialog=gtk_dialog_new_with_buttons(_("Group Properties"),NULL,GTK_DIALOG_MODAL,GTK_STOCK_OK,GTK_RESPONSE_OK,NULL);
 		
 	gtk_dialog_set_default_response(GTK_DIALOG(dialog),GTK_RESPONSE_OK);
 	
-	label1=gtk_label_new("Group name:");
-	label2=gtk_label_new("Contains number of Files:");
+	label1=gtk_label_new(_("Group name:"));
+	label2=gtk_label_new(_("Contains number of Files:"));
 	
 	filename=gtk_label_new(nodename);
 
@@ -142,7 +146,20 @@ void group_properties_gui(GtkTreeModel *tree_model,GtkTreeIter *iter)
 	gtk_misc_set_alignment(GTK_MISC(label1),0,0);
 	gtk_misc_set_alignment(GTK_MISC(label2),0,0);
 	
+
+#if GTK_MAJOR_VERSION>=3
+	table=gtk_grid_new();
 	
+	gtk_grid_attach(GTK_GRID(table),label1,0,0,1,1);
+	gtk_grid_attach(GTK_GRID(table),label2,0,1,1,1);
+	
+	gtk_grid_attach(GTK_GRID(table),filename,1,0,4,1);
+	gtk_grid_attach(GTK_GRID(table),number_of_files_label,1,1,4,1);
+	
+	gtk_grid_set_row_spacing (GTK_GRID (table), 6);
+	gtk_grid_set_column_spacing (GTK_GRID (table), 6);
+	
+#else	
 	table=gtk_table_new(3,2,FALSE);
 	
 	gtk_table_attach_defaults(GTK_TABLE(table),label1,0,1,0,1);
@@ -155,7 +172,7 @@ void group_properties_gui(GtkTreeModel *tree_model,GtkTreeIter *iter)
 	gtk_table_set_col_spacings(GTK_TABLE(table),5);
 	
 	gtk_container_set_border_width(GTK_CONTAINER(table),5);
-	
+#endif	
 	GtkWidget *container_vbox=gtk_dialog_get_content_area(GTK_DIALOG(dialog));
 	gtk_box_pack_start(GTK_BOX(container_vbox),table,TRUE,TRUE,0);
 
@@ -197,7 +214,7 @@ void file_properties_gui(GtkTreeModel *model,GtkTreeIter *iter)
 	debug_printf((gchar*)"Node name: %s\n",nodename);
 	debug_printf((gchar*)"File name: %s\n",filePath);
 		
-	dialog=gtk_dialog_new_with_buttons("File Properties",NULL,GTK_DIALOG_MODAL,GTK_STOCK_OK,GTK_RESPONSE_OK,NULL);
+	dialog=gtk_dialog_new_with_buttons(_("File Properties"),NULL,GTK_DIALOG_MODAL,GTK_STOCK_OK,GTK_RESPONSE_OK,NULL);
 		
 	gtk_dialog_set_default_response(GTK_DIALOG(dialog),GTK_RESPONSE_OK);
 		
@@ -221,9 +238,9 @@ void file_properties_gui(GtkTreeModel *model,GtkTreeIter *iter)
 	
 	size_string=g_strdup_printf("%d bytes",(int)(file_status.st_size));
 	
-	label1=gtk_label_new("Filename:");
-	label2=gtk_label_new("Path:");
-	label3=gtk_label_new("File size:");
+	label1=gtk_label_new(_("Filename:"));
+	label2=gtk_label_new(_("Path:"));
+	label3=gtk_label_new(_("File size:"));
 	
 	filename=gtk_label_new(nodename);
 	path=gtk_label_new(absFilePath/*sClickedNodeName*/);
@@ -237,7 +254,21 @@ void file_properties_gui(GtkTreeModel *model,GtkTreeIter *iter)
 	gtk_misc_set_alignment(GTK_MISC(label2),0,0);
 	gtk_misc_set_alignment(GTK_MISC(label3),0,0);
 	
+#if GTK_MAJOR_VERSION>=3
+	table=gtk_grid_new();
 	
+	gtk_grid_attach(GTK_GRID(table),label1,0,0,1,1);
+	gtk_grid_attach(GTK_GRID(table),label2,0,1,1,1);
+	gtk_grid_attach(GTK_GRID(table),label3,0,2,1,1);
+	
+	gtk_grid_attach(GTK_GRID(table),filename,1,0,4,1);
+	gtk_grid_attach(GTK_GRID(table),path,1,1,4,1);
+	gtk_grid_attach(GTK_GRID(table),filesize_label,1,2,4,1);
+	
+	gtk_grid_set_row_spacing (GTK_GRID (table), 6);
+	gtk_grid_set_column_spacing (GTK_GRID (table), 6);
+	
+#else
 	table=gtk_table_new(3,2,FALSE);
 	
 	gtk_table_attach_defaults(GTK_TABLE(table),label1,0,1,0,1);
@@ -252,7 +283,7 @@ void file_properties_gui(GtkTreeModel *model,GtkTreeIter *iter)
 	gtk_table_set_col_spacings(GTK_TABLE(table),5);
 	
 	gtk_container_set_border_width(GTK_CONTAINER(table),5);
-	
+#endif	
 	
 	container_vbox=gtk_dialog_get_content_area(GTK_DIALOG(dialog));
 	gtk_box_pack_start(GTK_BOX(container_vbox),table,TRUE,TRUE,0);
