@@ -1,7 +1,7 @@
 /**
  * recent_files.c - list of recently opened files
  *
- *  Copyright 2011 Andreas Rönnquist
+ *  Copyright 2011-2012 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  * 
@@ -22,7 +22,9 @@
 
 #include <gtk/gtk.h>
 #include <string.h>
+#include <glib/gi18n.h>
 
+#include <locale.h>
 
 #include "recent_files.h"
 #include "prefs.h"
@@ -72,7 +74,11 @@ GtkTreeStore* create_treestore_recent(GError **err)
 		result= gtk_tree_store_new(COLUMN_EOL, TYPE_ITEMTYPE, TYPE_FILEPATH, TYPE_FILENAME, TYPE_FILESIZE, TYPE_FONTWEIGHT, TYPE_FONTWEIGHTSET, TYPE_ICON, TYPE_EXPANDED);
 		
 	if (result == NULL) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create GtkTreeStore, gtk_tree_store_new() = NULL", __func__);
+		g_set_error(err, APP_SCITEPROJ_ERROR, -1, 
+			"%s: %s, gtk_tree_store_new() = NULL",
+			__func__,
+			"Couldn't init treestore"
+		);
 	}
 	
 	
@@ -96,7 +102,11 @@ GtkWidget *init_recent_files(GError **err)
 	
 	// add a scrolledwindow for recent files
 	if (!(recentScrolledWindow=gtk_scrolled_window_new(NULL,NULL))) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create recent scrolled window, gtk_scrolled_window_new() = NULL", __func__);
+		g_set_error(err, APP_SCITEPROJ_ERROR, -1, 
+			"%s: %s, gtk_scrolled_window_new() = NULL", 
+			__func__,
+			"Couldn't init recent scrolled window"
+		);
 		
 		goto EXITPOINT;
 	} 
@@ -105,13 +115,23 @@ GtkWidget *init_recent_files(GError **err)
 
 	
 	if ((recentTreeStore=create_treestore_recent(&tempErr))==NULL) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1 ,"%s: Could not create the recent treestore", tempErr->message);
+		if (tempErr) {
+			g_set_error(err, APP_SCITEPROJ_ERROR, -1 ,
+				"%s: %s", 
+				tempErr->message,
+				"Coudn't init recent treestore"
+			);
+		}
 		goto EXITPOINT;
 	}
 	
 	
 	if (!(recentTreeView=gtk_tree_view_new_with_model(GTK_TREE_MODEL(recentTreeStore)))) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create GtkTreeView, gtk_tree_view_new_with_model() = NULL", __func__);
+		g_set_error(err, APP_SCITEPROJ_ERROR, -1, 
+			"%s: %s, gtk_tree_view_new_with_model() = NULL", 
+			__func__,
+			"Couldn't init recent gtk_tree_view"
+			);
 		
 		goto EXITPOINT;
 	}
@@ -121,22 +141,34 @@ GtkWidget *init_recent_files(GError **err)
 	gtk_container_add(GTK_CONTAINER(recentScrolledWindow), recentTreeView);
 
 	if (!(recentCellRenderer = gtk_cell_renderer_text_new())) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create GtkCellRenderer, gtk_cell_renderer_text_new() = NULL", __func__);
+		g_set_error(err, APP_SCITEPROJ_ERROR, -1, 
+			"%s: %s, gtk_cell_renderer_text_new() = NULL", 
+			__func__,
+			"Couldn't init recent gtk_cell_renderer"
+		);
 		
 		goto EXITPOINT;
 	}
 	
 		
 	if (!(recentColumn1 = gtk_tree_view_column_new())) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create GtkTreeViewColumn, gtk_tree_view_column_new() = NULL", __func__);
+		g_set_error(err, APP_SCITEPROJ_ERROR, -1,
+			"%s: %s, gtk_tree_view_column_new() = NULL", 
+			__func__,
+			"Couldn't init recent gtk_tree_view_column"
+		);
 		
 		goto EXITPOINT;
 	}
 	
-	g_object_set(recentColumn1,"title","Recently opened files:",NULL);
+	g_object_set(recentColumn1,"title",_("Recently opened files:"),NULL);
 	
 	if (!(recentPixbuffCellRenderer = gtk_cell_renderer_pixbuf_new())) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create GtkCellRenderer, gtk_cell_renderer_pixbuf_new() = NULL", __func__);
+		g_set_error(err, APP_SCITEPROJ_ERROR, -1, 
+			"%s: %s, gtk_cell_renderer_pixbuf_new() = NULL",
+			__func__,
+			"Couldn't init recent gtk_cell_renderer_pixbuf"
+		);
 		
 		goto EXITPOINT;
 	}
@@ -497,7 +529,11 @@ static void recent_tree_row_activated_cb(GtkTreeView *treeView, GtkTreePath *pat
 	fixed=fix_path((gchar*)get_project_directory(),relFilePath);
 	
 	if ((command = g_strdup_printf("open:%s\n", fixed)) == NULL) {
-		g_set_error(&err, APP_SCITEPROJ_ERROR, -1, "%s: Error formatting Scite director command, g_strdup_printf() = NULL", __func__);
+		g_set_error(&err, APP_SCITEPROJ_ERROR, -1, 
+			"%s: %s, g_strdup_printf() = NULL", 
+			__func__,
+			"Error formatting SciTE command"
+		);
 	}
 	else {
 		if (send_scite_command(command, &err)) {
@@ -513,7 +549,7 @@ static void recent_tree_row_activated_cb(GtkTreeView *treeView, GtkTreePath *pat
 			
 			gchar *statusbar_text=NULL;
 			
-			statusbar_text=g_strdup_printf("Opened %s",remove_newline(get_filename_from_full_path(command)));
+			statusbar_text=g_strdup_printf(_("Opened %s"),remove_newline(get_filename_from_full_path(command)));
 			
 			set_statusbar_text(statusbar_text);
 			
@@ -524,7 +560,10 @@ static void recent_tree_row_activated_cb(GtkTreeView *treeView, GtkTreePath *pat
 //EXITPOINT:
 	
 	if (err != NULL) {
-		dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "Could not open selected file: \n\n%s", err->message);
+		dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
+			_("Could not open selected file: \n\n%s"), 
+			err->message
+		);
 		
 		gtk_dialog_run(GTK_DIALOG (dialog));
 	}
@@ -562,7 +601,10 @@ void popup_remove_recent_file_cb()
 EXITPOINT:
 	
 	if (err != NULL) {
-		dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "Could not open selected file: \n\n%s", err->message);
+		dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
+			_("Could not open selected file: \n\n%s"),
+			err->message
+		);
 		
 		gtk_dialog_run(GTK_DIALOG (dialog));
 	}
