@@ -1,7 +1,7 @@
 /**
  * scite_utils_linux.c - Code for working with Scite (Linux version)
  *
- *  Copyright 2006 Roy Wood, 2009-2011 Andreas Rönnquist
+ *  Copyright 2006 Roy Wood, 2009-2012 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  * 
@@ -25,6 +25,9 @@
 
 #include <gdk/gdkx.h>
 #include <X11/Xlib.h>
+#include <glib/gi18n.h>
+
+#include <locale.h>
 
 #include <stdlib.h>
 #include <string.h>
@@ -144,7 +147,10 @@ gboolean scite_pipe_read_ready_cb(GIOChannel *source, GIOCondition condition, gp
 	
 	if (condition & G_IO_IN) {
 		if (g_io_channel_read_chars(source, buff, sizeof(buff) - 1, &bytes_read, &error) != G_IO_STATUS_NORMAL) {
-			g_print("%s: Error calling g_io_channel_read_chars() = %s\n", __func__, (error != NULL) ? error->message : "<unknown>");
+			g_print("%s: %s = %s\n", 
+				__func__, 
+				"g_io_channel_read_chars failed",
+				(error != NULL) ? error->message : "<unknown>");
 		}
 		else {
 			if ((bytes_read-1)!=0) {
@@ -175,7 +181,7 @@ gboolean scite_pipe_read_ready_cb(GIOChannel *source, GIOCondition condition, gp
 					
 					gchar *file=get_filename_from_full_path(buff);
 					
-					status_string=g_strdup_printf("Closed %s",file);
+					status_string=g_strdup_printf(_("Closed %s"),file);
 					
 					set_statusbar_text(status_string);
 					
@@ -184,7 +190,7 @@ gboolean scite_pipe_read_ready_cb(GIOChannel *source, GIOCondition condition, gp
 				
 				if (g_str_has_prefix(buff, "closing:")) {
 					
-					set_statusbar_text("Closed SciTE");
+					set_statusbar_text(_("Closed SciTE"));
 					
 				}
 				
@@ -194,7 +200,7 @@ gboolean scite_pipe_read_ready_cb(GIOChannel *source, GIOCondition condition, gp
 					
 					gchar *file=get_filename_from_full_path(buff);
 					
-					status_string=g_strdup_printf("Switched to %s",file);
+					status_string=g_strdup_printf(_("Switched to %s"),file);
 					
 					set_statusbar_text(status_string);
 					
@@ -207,7 +213,7 @@ gboolean scite_pipe_read_ready_cb(GIOChannel *source, GIOCondition condition, gp
 					
 					gchar *file=get_filename_from_full_path(buff);
 					
-					status_string=g_strdup_printf("Opened %s",file);
+					status_string=g_strdup_printf(_("Opened %s"),file);
 					
 					set_statusbar_text(status_string);
 					
@@ -330,7 +336,9 @@ gboolean launch_scite(gchar *instring,GError **err)
 			
 		if (setenv(ipcDirectorName, responsePipePath, TRUE)) {
 			errCode = errno;
-			g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not launch Scite, setenv(\"%s\", \"%s\") failed, errno = %d = %s", __func__, ipcDirectorName, responsePipePath, errCode, strerror(errCode));
+			g_set_error(err, APP_SCITEPROJ_ERROR, -1, 
+				"%s: Could not launch Scite, setenv(\"%s\", \"%s\") failed, error = %s", 
+			__func__, ipcDirectorName, responsePipePath, strerror(errCode));
 			goto EXITPOINT;
 		}
 		
@@ -340,7 +348,9 @@ gboolean launch_scite(gchar *instring,GError **err)
 		
 		if (setenv(ipcSciteName, requestPipePath, TRUE)) {
 			errCode = errno;
-			g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not launch Scite, setenv(\"%s\", \"%s\") failed, errno = %d = %s", __func__, ipcSciteName, requestPipePath, errCode, strerror(errCode));
+			g_set_error(err, APP_SCITEPROJ_ERROR, -1, 
+				"%s: Could not launch Scite, setenv(\"%s\", \"%s\") failed, error = %s", 
+				__func__, ipcSciteName, requestPipePath, strerror(errCode));
 			goto EXITPOINT;
 		}
 		
@@ -350,14 +360,16 @@ gboolean launch_scite(gchar *instring,GError **err)
 		if (remove(responsePipePath) && errno != ENOENT) {
 			errCode = errno;
 			g_set_error(err, APP_SCITEPROJ_ERROR, -1, 
-					"%s: Could not launch Scite, remove(\"%s\") failed, errno = %d = %s", 
-					__func__, responsePipePath, errCode, strerror(errCode));
+					"%s: Could not launch Scite, remove(\"%s\") failed, error = %s", 
+					__func__, responsePipePath, strerror(errCode));
 			goto EXITPOINT;
 		}
 		
 		if (remove(requestPipePath) && errno != ENOENT) {
 			errCode = errno;
-			g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not launch Scite, remove(\"%s\") failed, errno = %d = %s", __func__, requestPipePath, errCode, strerror(errCode));
+			g_set_error(err, APP_SCITEPROJ_ERROR, -1, 
+				"%s: Could not launch Scite, remove(\"%s\") failed, error = %s",
+				__func__, requestPipePath, strerror(errCode));
 			goto EXITPOINT;
 		}
 		
@@ -366,7 +378,9 @@ gboolean launch_scite(gchar *instring,GError **err)
 		
 		if (mkfifo(responsePipePath, 0777)) {
 			errCode = errno;
-			g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not launch Scite, mkfifo(\"%s\") failed, errno = %d = %s", __func__, responsePipePath, errCode, strerror(errCode));
+			g_set_error(err, APP_SCITEPROJ_ERROR, -1, 
+				"%s: Could not launch Scite, mkfifo(\"%s\") failed, error = %s",
+				__func__, responsePipePath, strerror(errCode));
 			goto EXITPOINT;
 		}
 		
@@ -375,7 +389,9 @@ gboolean launch_scite(gchar *instring,GError **err)
 		
 		if ((sResponsePipeFD = open(responsePipePath, O_RDONLY | O_NONBLOCK)) <= 0) {
 			errCode = errno;
-			g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not launch Scite, open(\"%s\") failed, errno = %d = %s", __func__, responsePipePath, errCode, strerror(errCode));
+			g_set_error(err, APP_SCITEPROJ_ERROR, -1,
+				"%s: Could not launch Scite, open(\"%s\") failed, error = %s",
+				__func__, responsePipePath, strerror(errCode));
 			goto EXITPOINT;
 		}
 		
@@ -383,12 +399,16 @@ gboolean launch_scite(gchar *instring,GError **err)
 		
 		if ((sResponsePipeGIOChannel = g_io_channel_unix_new(sResponsePipeFD)) == NULL) {
 			errCode = errno;
-			g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not launch Scite, g_io_channel_unix_new(\"%s\") failed, errno = %d = %s", __func__, responsePipePath, errCode, strerror(errCode));
+			g_set_error(err, APP_SCITEPROJ_ERROR, -1,
+				"%s: Could not launch Scite, g_io_channel_unix_new(\"%s\") failed, error = %s",
+				__func__, responsePipePath, strerror(errCode));
 			goto EXITPOINT;
 		}
 		
 		if ((g_io_channel_set_encoding(sResponsePipeGIOChannel, NULL, err)) != G_IO_STATUS_NORMAL) {
-			g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not launch Scite, g_io_channel_set_encoding( ) failed, error = %s", __func__, (err != NULL && *err != NULL) ? (*err)->message : "<unknown>");
+			g_set_error(err, APP_SCITEPROJ_ERROR, -1,
+				"%s: Could not launch Scite, g_io_channel_set_encoding( ) failed, error = %s",
+				__func__, (err != NULL && *err != NULL) ? (*err)->message : "<unknown>");
 			goto EXITPOINT;
 		}
 		
@@ -399,7 +419,9 @@ gboolean launch_scite(gchar *instring,GError **err)
 		
 		if (pipe(childPipePair)) {
 			errCode = errno;
-			g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not launch Scite, pipe( ) failed, errno = %d = %s", __func__, errCode, strerror(errCode));
+			g_set_error(err, APP_SCITEPROJ_ERROR, -1,
+				"%s: Could not launch Scite, pipe( ) failed, errno = %d = %s",
+				__func__, errCode, strerror(errCode));
 			goto EXITPOINT;
 		}
 		
@@ -471,7 +493,9 @@ gboolean launch_scite(gchar *instring,GError **err)
 		
 		if (childPID == -1) {
 			errCode = errno;
-			g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not launch Scite, fork() failed, errno = %d = %s", __func__, errCode, strerror(errCode));
+			g_set_error(err, APP_SCITEPROJ_ERROR, -1,
+				"%s: Could not launch Scite, fork() failed, errno = %d = %s",
+				__func__, errCode, strerror(errCode));
 			goto EXITPOINT;
 		}
 		else if (childPID == 0) {
@@ -562,7 +586,7 @@ gboolean launch_scite(gchar *instring,GError **err)
 			// No luck yet, so display a progress dialog and wait a bit longer
 			
 			if (usecs > usecsDialogDelay && !dialog) {
-				dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_CANCEL, "Connecting to Scite....");
+				dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_CANCEL, _("Connecting to Scite...."));
 				g_signal_connect(dialog, "response", G_CALLBACK(cancel_button_cb), (void *) &userClickedCancel);
 				gtk_widget_show_all(dialog);
 			}
@@ -584,7 +608,9 @@ gboolean launch_scite(gchar *instring,GError **err)
 		
 		if ((sRequestPipeFD = open(requestPipePath, O_WRONLY | O_NONBLOCK)) <= 0) {
 			errCode = errno;
-			g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not launch Scite, open(\"%s\") failed, errno = %d = %s", __func__, requestPipePath, errCode, strerror(errCode));
+			g_set_error(err, APP_SCITEPROJ_ERROR, -1,
+				"%s: Could not launch Scite, open(\"%s\") failed, error = %s",
+				__func__, requestPipePath, strerror(errCode));
 			goto EXITPOINT;
 		}
 		
@@ -609,7 +635,7 @@ gboolean launch_scite(gchar *instring,GError **err)
 		
 		resultCode = TRUE;
 		
-		set_statusbar_text("Launched SciTE");
+		set_statusbar_text(_("Launched SciTE"));
 	}
 	
 	debug_printf("All done launching SciTE...\n");
@@ -661,7 +687,9 @@ gboolean send_scite_command(gchar *command, GError **err)
 	
 	if ((write(sRequestPipeFD, command, commandLength)) < commandLength) {
 		int errCode = errno;
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not send command to Scite, write(\"%s\") failed, errno = %d = %s", __func__, command, errCode, strerror(errCode));
+		g_set_error(err, APP_SCITEPROJ_ERROR, -1, 
+			"%s: Could not send command to Scite, write(\"%s\") failed, errno = %d = %s",
+			__func__, command, errCode, strerror(errCode));
 		goto EXITPOINT;
 	}
 	
@@ -702,7 +730,8 @@ gboolean activate_scite(GError **err)
 		sDisplay = XOpenDisplay(displayName);
 		
 		if (sDisplay == NULL) {
-			g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not open X display, XOpenDisplay() = NULL", __func__);
+			g_set_error(err, APP_SCITEPROJ_ERROR, -1,
+				"%s: Could not open X display, XOpenDisplay() = NULL", __func__);
 			goto EXITPOINT;
 		}
 	}
@@ -710,7 +739,8 @@ gboolean activate_scite(GError **err)
 	// Do we actually have a reference to the SciTE window?
 	
 	if (sSciteWin == 0) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not activate SciTE window, X11 window ID invalid", __func__);
+		g_set_error(err, APP_SCITEPROJ_ERROR, -1, 
+			"%s: Could not activate SciTE window, X11 window ID invalid", __func__);
 		goto EXITPOINT;
 	}
 	
