@@ -1,6 +1,7 @@
-/* scite_utils_linux.h - Code for working with Scite (Linux version)
+/**
+ * scite_utils_linux.h - Code for working with Scite (Linux version)
  *
- *  Copyright 2006 Roy Wood, 2009-2011 Andreas Ronnquist
+ *  Copyright 2006 Roy Wood, 2009-2011 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  * 
@@ -47,6 +48,8 @@ gboolean check_if_scite_exists();
 
 void init_scite_connection();
 
+gboolean open_filename(gchar *filename,gchar *project_directory,GError **err);
+
 
 #endif /*__HEADER_SCITE_UTILS_*/
 
