@@ -1,7 +1,7 @@
 /**
  * statusbar.c - statusbar for SciteProj
  *
- *  Copyright 2009-2011 Andreas Rönnquist
+ *  Copyright 2009-2012 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  * 
@@ -23,6 +23,9 @@
 #include <string.h>
 #include <stdlib.h>
 #include <gtk/gtk.h>
+#include <glib/gi18n.h>
+
+#include <locale.h>
 
 #include "statusbar.h"
 
@@ -36,7 +39,7 @@ guint context_id;
 /**
  *		init_statusbar
  */
-gboolean init_statusbar(GtkWidget *widget,GError **err)
+gboolean init_statusbar(GtkWidget *widget,GtkWidget *next_to,GError **err)
 {
 	statusbar=gtk_statusbar_new();
 	
@@ -51,11 +54,16 @@ gboolean init_statusbar(GtkWidget *widget,GError **err)
 
 	context_id=gtk_statusbar_get_context_id(GTK_STATUSBAR(statusbar),"Info");
 	
-	set_statusbar_text("Welcome to SciteProj\n");
+	set_statusbar_text(_("Welcome to SciteProj\n"));
 	
 	gtk_widget_set_size_request(statusbar, -1, 20);
 	
+#if GTK_MAJOR_VERSION>=3
+	gtk_grid_attach_next_to(GTK_GRID(widget),statusbar,next_to,GTK_POS_BOTTOM,1,1);
+#else
 	gtk_box_pack_end (GTK_BOX (widget), statusbar,FALSE, FALSE, 0);
+#endif
+	
 	gtk_widget_show (statusbar);
 
 	
@@ -68,32 +76,35 @@ gboolean init_statusbar(GtkWidget *widget,GError **err)
  */
 void set_statusbar_text(const gchar *text)
 {
-	int co=0;
-	// new string - fill it with characters from text indata, but skip
-	// non-showable characters.
-	
-	gchar *newstring=(gchar*)(g_malloc((int)(strlen(text)+1)));
-	
-	int newco=0;
-	for (co=0;co<(int)strlen(text);co++) {
-		if (text[co]!='\n') {
-			newstring[newco]=text[co];
-			newco++;
+	if (statusbar) {
+			
+		int co=0;
+		// new string - fill it with characters from text indata, but skip
+		// non-showable characters.
+		
+		gchar *newstring=(gchar*)(g_malloc((int)(strlen(text)+1)));
+		
+		int newco=0;
+		for (co=0;co<(int)strlen(text);co++) {
+			if (text[co]!='\n') {
+				newstring[newco]=text[co];
+				newco++;
+			}
 		}
+		
+		newstring[newco]='\0';
+		
+		// Pop what message that was previously on the statusbar stack
+		gtk_statusbar_pop(GTK_STATUSBAR(statusbar),context_id);
+		
+		// Push the new message (the statusbar will show the message that
+		// is on top of the statusbar stack, the one pushed will be shown)
+		// We popped the last one, because we don't take advantage of the 
+		// context_id system of the statusbar.
+		gtk_statusbar_push(GTK_STATUSBAR(statusbar),context_id,newstring);
+		
+		g_free(newstring);
 	}
-	
-	newstring[newco]='\0';
-	
-	// Pop what message that was previously on the statusbar stack
-	gtk_statusbar_pop(GTK_STATUSBAR(statusbar),context_id);
-	
-	// Push the new message (the statusbar will show the message that
-	// is on top of the statusbar stack, the one pushed will be shown)
-	// We popped the last one, because we don't take advantage of the 
-	// context_id system of the statusbar.
-	gtk_statusbar_push(GTK_STATUSBAR(statusbar),context_id,newstring);
-	
-	g_free(newstring);
 }
 
 
