@@ -1,7 +1,7 @@
 /**
  * statusbar.h - statusbar for SciteProj
  *
- *  Copyright 2009-2011 Andreas Rönnquist
+ *  Copyright 2009-2012 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  * 
@@ -22,7 +22,7 @@
 #ifndef __HEADER_STATUSBAR_
 #define __HEADER_STATUSBAR_
 
-gboolean init_statusbar(GtkWidget *hbox,GError **err);
+gboolean init_statusbar(GtkWidget *grid,GtkWidget *next_to,GError **err);
 
 void set_statusbar_text(const gchar *text);
 
