@@ -1,7 +1,7 @@
 /**
  * string_utils.c - misc string utils for SciteProj
  *
- *  Copyright 2006 Roy Wood, 2009-2011 Andreas Rönnquist
+ *  Copyright 2006 Roy Wood, 2009-2012 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  * 
@@ -22,6 +22,9 @@
 #include <glib.h>
 #include <stdio.h>
 #include <ctype.h>
+#include <glib/gi18n.h>
+
+#include <locale.h>
 
 #include "string_utils.h"
 #include "file_utils.h"
